changeset 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents 6da7fc87efaa
children 77aec9be0a51
files Core/ChunkedBuffer.cpp Core/ChunkedBuffer.h Core/Compression/BufferCompressor.cpp Core/Compression/BufferCompressor.h Core/Compression/ZlibCompressor.cpp Core/Compression/ZlibCompressor.h Core/DicomFormat/DicomArray.cpp Core/DicomFormat/DicomArray.h Core/DicomFormat/DicomElement.h Core/DicomFormat/DicomMap.cpp Core/DicomFormat/DicomMap.h Core/DicomFormat/DicomNullValue.h Core/DicomFormat/DicomString.h Core/DicomFormat/DicomTag.cpp Core/DicomFormat/DicomTag.h Core/DicomFormat/DicomValue.h Core/Enumerations.h Core/FileStorage.cpp Core/FileStorage.h Core/HttpServer/EmbeddedResourceHttpHandler.cpp Core/HttpServer/EmbeddedResourceHttpHandler.h Core/HttpServer/FilesystemHttpHandler.cpp Core/HttpServer/FilesystemHttpHandler.h Core/HttpServer/HttpHandler.cpp Core/HttpServer/HttpHandler.h Core/HttpServer/HttpOutput.cpp Core/HttpServer/HttpOutput.h Core/HttpServer/MongooseServer.cpp Core/HttpServer/MongooseServer.h Core/MultiThreading/BagOfRunnablesBySteps.cpp Core/MultiThreading/BagOfRunnablesBySteps.h Core/MultiThreading/IRunnableBySteps.h Core/OrthancException.cpp Core/OrthancException.h Core/PngWriter.cpp Core/PngWriter.h Core/SQLite/Connection.cpp Core/SQLite/Connection.h Core/SQLite/FunctionContext.cpp Core/SQLite/FunctionContext.h Core/SQLite/IScalarFunction.h Core/SQLite/README.txt Core/SQLite/Statement.cpp Core/SQLite/Statement.h Core/SQLite/StatementId.cpp Core/SQLite/StatementId.h Core/SQLite/StatementReference.cpp Core/SQLite/StatementReference.h Core/SQLite/Transaction.cpp Core/SQLite/Transaction.h Core/Toolbox.cpp Core/Toolbox.h Core/Uuid.cpp Core/Uuid.h
diffstat 54 files changed, 199 insertions(+), 199 deletions(-) [+]
line wrap: on
line diff
--- a/Core/SQLite/README.txt	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/README.txt	Sun Sep 16 09:28:56 2012 +0200
@@ -13,9 +13,9 @@
 
 * The reference counting mechanism has been reimplemented to make it 
   simpler.
-* The PalanthirException class is used for the exception mechanisms.
+* The OrthancException class is used for the exception mechanisms.
 * A statement is always valid (is_valid() always return true).
-* The classes and the methods have been renamed to meet Palanthir's
+* The classes and the methods have been renamed to meet Orthanc's
   coding conventions.
 
 
--- a/Core/ChunkedBuffer.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/ChunkedBuffer.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -24,7 +24,7 @@
 #include <string.h>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   void ChunkedBuffer::Clear()
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/ChunkedBuffer.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/ChunkedBuffer.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,7 +23,7 @@
 #include <list>
 #include <string>
 
-namespace Palanthir
+namespace Orthanc
 {
   class ChunkedBuffer
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Compression/BufferCompressor.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Compression/BufferCompressor.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "BufferCompressor.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   void BufferCompressor::Compress(std::string& output,
                                   const std::vector<uint8_t>& input)
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Compression/BufferCompressor.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Compression/BufferCompressor.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 #include <stdint.h>
 #include <vector>
 
-namespace Palanthir
+namespace Orthanc
 {
   class BufferCompressor
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Compression/ZlibCompressor.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Compression/ZlibCompressor.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,15 +23,15 @@
 #include <stdio.h>
 #include <string.h>
 #include <zlib.h>
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   void ZlibCompressor::SetCompressionLevel(uint8_t level)
   {
     if (level >= 10)
     {
-      throw PalanthirException("Zlib compression level must be between 0 (no compression) and 9 (highest compression");
+      throw OrthancException("Zlib compression level must be between 0 (no compression) and 9 (highest compression");
     }
   }
 
@@ -70,10 +70,10 @@
       switch (error)
       {
       case Z_MEM_ERROR:
-        throw PalanthirException(ErrorCode_NotEnoughMemory);
+        throw OrthancException(ErrorCode_NotEnoughMemory);
 
       default:
-        throw PalanthirException(ErrorCode_InternalError);
+        throw OrthancException(ErrorCode_InternalError);
       }  
     }
   }
@@ -91,7 +91,7 @@
 
     if (compressedSize < sizeof(size_t))
     {
-      throw PalanthirException("Zlib: The compressed buffer is ill-formed");
+      throw OrthancException("Zlib: The compressed buffer is ill-formed");
     }
 
     size_t uncompressedLength;
@@ -112,13 +112,13 @@
       switch (error)
       {
       case Z_DATA_ERROR:
-        throw PalanthirException("Zlib: Corrupted or incomplete compressed buffer");
+        throw OrthancException("Zlib: Corrupted or incomplete compressed buffer");
 
       case Z_MEM_ERROR:
-        throw PalanthirException(ErrorCode_NotEnoughMemory);
+        throw OrthancException(ErrorCode_NotEnoughMemory);
 
       default:
-        throw PalanthirException(ErrorCode_InternalError);
+        throw OrthancException(ErrorCode_InternalError);
       }  
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Compression/ZlibCompressor.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Compression/ZlibCompressor.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "BufferCompressor.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class ZlibCompressor : public BufferCompressor
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomArray.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomArray.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include <stdio.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   DicomArray::DicomArray(const DicomMap& map)
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomArray.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomArray.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 
 #include <vector>
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomArray : public boost::noncopyable
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomElement.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomElement.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,7 +23,7 @@
 #include "DicomValue.h"
 #include "DicomTag.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomElement : public boost::noncopyable
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomMap.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomMap.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,10 +23,10 @@
 #include <stdio.h>
 #include <memory>
 #include "DicomString.h"
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 
-namespace Palanthir
+namespace Orthanc
 {
   static DicomTag patientTags[] =
   {
@@ -178,7 +178,7 @@
 
     if (it == map_.end())
     {
-      throw PalanthirException("Inexistent tag");
+      throw OrthancException("Inexistent tag");
     }
     else
     {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomMap.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomMap.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -27,7 +27,7 @@
 #include <map>
 #include <json/json.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomMap : public boost::noncopyable
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomNullValue.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomNullValue.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "DicomValue.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomNullValue : public DicomValue
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomString.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomString.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include "DicomValue.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomString : public DicomValue
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomTag.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomTag.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,13 +20,13 @@
 
 #include "DicomTag.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <iostream>
 #include <iomanip>
 #include <stdio.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   bool DicomTag::operator< (const DicomTag& other) const
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomTag.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomTag.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -24,7 +24,7 @@
 #include <stdint.h>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomTag
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/DicomFormat/DicomValue.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/DicomFormat/DicomValue.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,7 +23,7 @@
 #include <boost/noncopyable.hpp>
 #include <string>
 
-namespace Palanthir
+namespace Orthanc
 {
   class DicomValue : public boost::noncopyable
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Enumerations.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Enumerations.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,9 +20,9 @@
 
 #pragma once
 
-#include "../PalanthirCppClient/HttpEnumerations.h"
+#include "../OrthancCppClient/HttpEnumerations.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   enum ErrorCode
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/FileStorage.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/FileStorage.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,13 +23,13 @@
 // http://stackoverflow.com/questions/1576272/storing-large-number-of-files-in-file-system
 // http://stackoverflow.com/questions/446358/storing-a-large-number-of-images
 
-#include "PalanthirException.h"
+#include "OrthancException.h"
 #include "Toolbox.h"
 #include "Uuid.h"
 
 #include <boost/filesystem/fstream.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   boost::filesystem::path FileStorage::GetPath(const std::string& uuid) const
   {
@@ -37,7 +37,7 @@
 
     if (!Toolbox::IsUuid(uuid))
     {
-      throw PalanthirException(ErrorCode_ParameterOutOfRange);
+      throw OrthancException(ErrorCode_ParameterOutOfRange);
     }
 
     fs::path path = root_;
@@ -60,14 +60,14 @@
     {
       if (!fs::is_directory(root))
       {
-        throw PalanthirException("The file storage root directory is a file");
+        throw OrthancException("The file storage root directory is a file");
       }
     }
     else
     {
       if (!fs::create_directories(root))
       {
-        throw PalanthirException("Unable to create the file storage root directory");
+        throw OrthancException("Unable to create the file storage root directory");
       }
     }
   }
@@ -96,14 +96,14 @@
     {
       if (!boost::filesystem::is_directory(path.parent_path()))
       {
-        throw PalanthirException("The subdirectory to be created is already occupied by a regular file");        
+        throw OrthancException("The subdirectory to be created is already occupied by a regular file");        
       }
     }
     else
     {
       if (!boost::filesystem::create_directories(path.parent_path()))
       {
-        throw PalanthirException("Unable to create a subdirectory in the file storage");        
+        throw OrthancException("Unable to create a subdirectory in the file storage");        
       }
     }
 
@@ -111,7 +111,7 @@
     f.open(path, std::ofstream::out | std::ios::binary);
     if (!f.good())
     {
-      throw PalanthirException("Unable to create a new file in the file storage");
+      throw OrthancException("Unable to create a new file in the file storage");
     }
 
     if (size != 0)
@@ -120,7 +120,7 @@
       if (!f.good())
       {
         f.close();
-        throw PalanthirException("Unable to write to the new file in the file storage");
+        throw OrthancException("Unable to write to the new file in the file storage");
       }
     }
 
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/FileStorage.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/FileStorage.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 
 #include "Compression/BufferCompressor.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class FileStorage : public boost::noncopyable
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/EmbeddedResourceHttpHandler.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/EmbeddedResourceHttpHandler.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,12 +20,12 @@
 
 #include "EmbeddedResourceHttpHandler.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <stdio.h>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   EmbeddedResourceHttpHandler::EmbeddedResourceHttpHandler(
     const std::string& baseUri,
@@ -65,9 +65,9 @@
       size_t size = EmbeddedResources::GetDirectoryResourceSize(resourceId_, resourcePath.c_str());
       output.AnswerBufferWithContentType(buffer, size, contentType);
     }
-    catch (PalanthirException& e)
+    catch (OrthancException& e)
     {
-      output.SendHeader(Palanthir_HttpStatus_404_NotFound);
+      output.SendHeader(Orthanc_HttpStatus_404_NotFound);
     }
   } 
 }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/EmbeddedResourceHttpHandler.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/EmbeddedResourceHttpHandler.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 #include <EmbeddedResources.h>   // Autogenerated file
 #include <boost/shared_ptr.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   class EmbeddedResourceHttpHandler : public HttpHandler
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/FilesystemHttpHandler.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/FilesystemHttpHandler.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,12 +20,12 @@
 
 #include "FilesystemHttpHandler.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <boost/filesystem.hpp>
 
 
-namespace Palanthir
+namespace Orthanc
 {
   struct FilesystemHttpHandler::PImpl
   {
@@ -91,7 +91,7 @@
     if (!fs::exists(pimpl_->root_) || 
         !fs::is_directory(pimpl_->root_))
     {
-      throw PalanthirException("The path does not point to a directory");
+      throw OrthancException("The path does not point to a directory");
     }
   }
 
@@ -136,7 +136,7 @@
     }
     else
     {
-      output.SendHeader(Palanthir_HttpStatus_404_NotFound);
+      output.SendHeader(Orthanc_HttpStatus_404_NotFound);
     }
   } 
 }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/FilesystemHttpHandler.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/FilesystemHttpHandler.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -24,7 +24,7 @@
 
 #include <boost/shared_ptr.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   class FilesystemHttpHandler : public HttpHandler
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/HttpHandler.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/HttpHandler.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -22,7 +22,7 @@
 
 #include <string.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   static void SplitGETNameValue(HttpHandler::Arguments& result,
                                 const char* start,
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/HttpHandler.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/HttpHandler.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -26,7 +26,7 @@
 #include "HttpOutput.h"
 #include "../Toolbox.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class HttpHandler
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/HttpOutput.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/HttpOutput.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,11 +23,11 @@
 #include <vector>
 #include <stdio.h>
 #include <boost/lexical_cast.hpp>
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 #include "../Toolbox.h"
-#include "../../PalanthirCppClient/HttpException.h"
+#include "../../OrthancCppClient/HttpException.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   void HttpOutput::SendString(const std::string& s)
   {
@@ -82,26 +82,26 @@
   void HttpOutput::SendMethodNotAllowedError(const std::string& allowed)
   {
     std::string s = 
-      "HTTP/1.1 405 " + std::string(HttpException::GetDescription(Palanthir_HttpStatus_405_MethodNotAllowed)) +
+      "HTTP/1.1 405 " + std::string(HttpException::GetDescription(Orthanc_HttpStatus_405_MethodNotAllowed)) +
       "\r\nAllow: " + allowed + 
       "\r\n\r\n";
     Send(&s[0], s.size());
   }
 
 
-  void HttpOutput::SendHeader(Palanthir_HttpStatus status)
+  void HttpOutput::SendHeader(Orthanc_HttpStatus status)
   {
-    if (status == Palanthir_HttpStatus_200_Ok ||
-        status == Palanthir_HttpStatus_405_MethodNotAllowed)
+    if (status == Orthanc_HttpStatus_200_Ok ||
+        status == Orthanc_HttpStatus_405_MethodNotAllowed)
     {
-      throw PalanthirException("Please use the dedicated methods to this HTTP status code in HttpOutput");
+      throw OrthancException("Please use the dedicated methods to this HTTP status code in HttpOutput");
     }
     
     SendHeaderInternal(status);
   }
 
 
-  void HttpOutput::SendHeaderInternal(Palanthir_HttpStatus status)
+  void HttpOutput::SendHeaderInternal(Orthanc_HttpStatus status)
   {
     std::string s = "HTTP/1.1 " + 
       boost::lexical_cast<std::string>(status) +
@@ -136,7 +136,7 @@
     FILE* fp = fopen(path.c_str(), "rb");
     if (!fp)
     {
-      SendHeaderInternal(Palanthir_HttpStatus_500_InternalServerError);
+      SendHeaderInternal(Orthanc_HttpStatus_500_InternalServerError);
       return;
     }
   
@@ -180,7 +180,7 @@
   void HttpOutput::Redirect(const std::string& path)
   {
     std::string s = 
-      "HTTP/1.1 301 " + std::string(HttpException::GetDescription(Palanthir_HttpStatus_301_MovedPermanently)) + 
+      "HTTP/1.1 301 " + std::string(HttpException::GetDescription(Orthanc_HttpStatus_301_MovedPermanently)) + 
       "\r\nLocation: " + path +
       "\r\n\r\n";
     Send(&s[0], s.size());  
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/HttpOutput.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/HttpOutput.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,12 +25,12 @@
 #include "../Enumerations.h"
 #include "../FileStorage.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class HttpOutput
   {
   private:
-    void SendHeaderInternal(Palanthir_HttpStatus status);
+    void SendHeaderInternal(Orthanc_HttpStatus status);
 
     void SendOkHeader(const char* contentType,
                       bool hasContentLength,
@@ -56,7 +56,7 @@
 
     void SendMethodNotAllowedError(const std::string& allowed);
 
-    void SendHeader(Palanthir_HttpStatus status);
+    void SendHeader(Orthanc_HttpStatus status);
 
 
     // Higher-level constructs to send entire files or buffers -------------------
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/MongooseServer.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/MongooseServer.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -31,17 +31,17 @@
 #include <stdio.h>
 #include <boost/thread.hpp>
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 #include "../ChunkedBuffer.h"
 #include "mongoose.h"
 
 
-#define PALANTHIR_REALM "Palanthir Secure Area"
+#define ORTHANC_REALM "Orthanc Secure Area"
 
 static const long LOCALHOST = (127ll << 24) + 1ll;
 
 
-namespace Palanthir
+namespace Orthanc
 {
   static const char multipart[] = "multipart/form-data; boundary=";
   static unsigned int multipartLength = sizeof(multipart) / sizeof(char) - 1;
@@ -402,7 +402,7 @@
   static void SendUnauthorized(HttpOutput& output)
   {
     std::string s = "HTTP/1.1 401 Unauthorized\r\n" 
-      "WWW-Authenticate: Basic realm=\"" PALANTHIR_REALM "\""
+      "WWW-Authenticate: Basic realm=\"" ORTHANC_REALM "\""
       "\r\n\r\n";
     output.Send(&s[0], s.size());
   }
@@ -481,7 +481,7 @@
         HttpHandler::Arguments::const_iterator ct = headers.find("content-type");
         if (ct == headers.end())
         {
-          output.SendHeader(Palanthir_HttpStatus_400_BadRequest);
+          output.SendHeader(Orthanc_HttpStatus_400_BadRequest);
           return (void*) "";
         }
 
@@ -501,11 +501,11 @@
         switch (status)
         {
         case PostDataStatus_NoLength:
-          output.SendHeader(Palanthir_HttpStatus_411_LengthRequired);
+          output.SendHeader(Orthanc_HttpStatus_411_LengthRequired);
           return (void*) "";
 
         case PostDataStatus_Failure:
-          output.SendHeader(Palanthir_HttpStatus_400_BadRequest);
+          output.SendHeader(Orthanc_HttpStatus_400_BadRequest);
           return (void*) "";
 
         case PostDataStatus_Pending:
@@ -528,15 +528,15 @@
           handler->Handle(output, std::string(request->request_method),
                           uri, headers, arguments, postData);
         }
-        catch (PalanthirException& e)
+        catch (OrthancException& e)
         {
           std::cerr << "MongooseServer Exception [" << e.What() << "]" << std::endl;
-          output.SendHeader(Palanthir_HttpStatus_500_InternalServerError);        
+          output.SendHeader(Orthanc_HttpStatus_500_InternalServerError);        
         }
       }
       else
       {
-        output.SendHeader(Palanthir_HttpStatus_404_NotFound);
+        output.SendHeader(Orthanc_HttpStatus_404_NotFound);
       }
 
       // Mark as processed
@@ -599,7 +599,7 @@
       pimpl_->context_ = mg_start(&Callback, this, options);
       if (!pimpl_->context_)
       {
-        throw PalanthirException("Unable to launch the Mongoose server");
+        throw OrthancException("Unable to launch the Mongoose server");
       }
     }
   }
@@ -654,10 +654,10 @@
   {
     Stop();
 
-#if PALANTHIR_SSL_ENABLED == 0
+#if ORTHANC_SSL_ENABLED == 0
     if (enabled)
     {
-      throw PalanthirException("Palanthir has been built without SSL support");
+      throw OrthancException("Orthanc has been built without SSL support");
     }
     else
     {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/HttpServer/MongooseServer.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/MongooseServer.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -27,7 +27,7 @@
 #include <stdint.h>
 #include <boost/shared_ptr.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   class ChunkStore;
 
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/MultiThreading/BagOfRunnablesBySteps.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/MultiThreading/BagOfRunnablesBySteps.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,7 +23,7 @@
 #include <stack>
 #include <boost/thread.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   struct BagOfRunnablesBySteps::PImpl
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/MultiThreading/BagOfRunnablesBySteps.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/MultiThreading/BagOfRunnablesBySteps.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 #include <boost/noncopyable.hpp>
 #include <boost/shared_ptr.hpp>
 
-namespace Palanthir
+namespace Orthanc
 {
   class BagOfRunnablesBySteps : public boost::noncopyable
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/MultiThreading/IRunnableBySteps.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/MultiThreading/IRunnableBySteps.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #pragma once
 
-namespace Palanthir
+namespace Orthanc
 {
   class IRunnableBySteps
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/OrthancException.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/OrthancException.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -18,11 +18,11 @@
  **/
 
 
-#include "PalanthirException.h"
+#include "OrthancException.h"
 
-namespace Palanthir
+namespace Orthanc
 {
-  const char* PalanthirException::What() const
+  const char* OrthancException::What() const
   {
     if (error_ == ErrorCode_Custom)
     {
@@ -35,7 +35,7 @@
   }
 
 
-  const char* PalanthirException::GetDescription(ErrorCode error)
+  const char* OrthancException::GetDescription(ErrorCode error)
   {
     switch (error)
     {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/OrthancException.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/OrthancException.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,9 +23,9 @@
 #include <string>
 #include "Enumerations.h"
 
-namespace Palanthir
+namespace Orthanc
 {
-  class PalanthirException
+  class OrthancException
   {
   private:
     ErrorCode error_;
@@ -34,13 +34,13 @@
   public:
     static const char* GetDescription(ErrorCode error);
 
-    PalanthirException(const std::string& custom)
+    OrthancException(const std::string& custom)
     {
       error_ = ErrorCode_Custom;
       custom_ = custom;
     }
 
-    PalanthirException(ErrorCode error)
+    OrthancException(ErrorCode error)
     {
       error_ = error;
     }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/PngWriter.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/PngWriter.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,7 +23,7 @@
 #include <vector>
 #include <stdint.h>
 #include <png.h>
-#include "PalanthirException.h"
+#include "OrthancException.h"
 #include "ChunkedBuffer.h"
 
 
@@ -58,7 +58,7 @@
 }*/
 
 
-namespace Palanthir
+namespace Orthanc
 {
   struct PngWriter::PImpl
   {
@@ -82,14 +82,14 @@
       (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL); //this, ErrorHandler, WarningHandler);
     if (!pimpl_->png_)
     {
-      throw PalanthirException(ErrorCode_NotEnoughMemory);
+      throw OrthancException(ErrorCode_NotEnoughMemory);
     }
 
     pimpl_->info_ = png_create_info_struct(pimpl_->png_);
     if (!pimpl_->info_)
     {
       png_destroy_write_struct(&pimpl_->png_, NULL);
-      throw PalanthirException(ErrorCode_NotEnoughMemory);
+      throw OrthancException(ErrorCode_NotEnoughMemory);
     }
   }
 
@@ -133,7 +133,7 @@
       break;
 
     default:
-      throw PalanthirException(ErrorCode_NotImplemented);
+      throw OrthancException(ErrorCode_NotImplemented);
     }
   }
 
@@ -180,7 +180,7 @@
     FILE* fp = fopen(filename, "wb");
     if (!fp)
     {
-      throw PalanthirException(ErrorCode_CannotWriteFile);
+      throw OrthancException(ErrorCode_CannotWriteFile);
     }    
 
     png_init_io(pimpl_->png_, fp);
@@ -188,7 +188,7 @@
     if (setjmp(png_jmpbuf(pimpl_->png_)))
     {
       // Error during writing PNG
-      throw PalanthirException(ErrorCode_CannotWriteFile);      
+      throw OrthancException(ErrorCode_CannotWriteFile);      
     }
 
     Compress(width, height, pitch, format);
@@ -223,7 +223,7 @@
     if (setjmp(png_jmpbuf(pimpl_->png_)))
     {
       // Error during writing PNG
-      throw PalanthirException(ErrorCode_InternalError);      
+      throw OrthancException(ErrorCode_InternalError);      
     }
 
     png_set_write_fn(pimpl_->png_, &chunks, MemoryCallback, NULL);
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/PngWriter.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/PngWriter.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,7 +25,7 @@
 #include <boost/shared_ptr.hpp>
 #include <string>
 
-namespace Palanthir
+namespace Orthanc
 {
   class PngWriter
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/Connection.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Connection.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -43,7 +43,7 @@
 
 
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -65,7 +65,7 @@
     {
       if (!db_)
       {
-        throw PalanthirException("SQLite: The database is not opened");
+        throw OrthancException("SQLite: The database is not opened");
       }
     }
 
@@ -73,7 +73,7 @@
     {
       if (db_) 
       {
-        throw PalanthirException("SQLite: Connection is already open");
+        throw OrthancException("SQLite: Connection is already open");
       }
 
       int err = sqlite3_open(path.c_str(), &db_);
@@ -81,7 +81,7 @@
       {
         Close();
         db_ = NULL;
-        throw PalanthirException("SQLite: Unable to open the database");
+        throw OrthancException("SQLite: Unable to open the database");
       }
 
       // Execute PRAGMAs at this point
@@ -133,7 +133,7 @@
       {
         if (i->second->GetReferenceCount() >= 1)
         {
-          throw PalanthirException("SQLite: This cached statement is already being referred to");
+          throw OrthancException("SQLite: This cached statement is already being referred to");
         }
 
         return *i->second;
@@ -154,7 +154,7 @@
       int error = sqlite3_exec(db_, sql, NULL, NULL, NULL);
       if (error == SQLITE_ERROR)
       {
-        throw PalanthirException("SQLite Execute error: " + std::string(sqlite3_errmsg(db_)));
+        throw OrthancException("SQLite Execute error: " + std::string(sqlite3_errmsg(db_)));
       }
       else
       {
@@ -275,7 +275,7 @@
     {
       if (!transactionNesting_)
       {
-        throw PalanthirException("Rolling back a nonexistent transaction");
+        throw OrthancException("Rolling back a nonexistent transaction");
       }
 
       transactionNesting_--;
@@ -294,7 +294,7 @@
     {
       if (!transactionNesting_) 
       {
-        throw PalanthirException("Committing a nonexistent transaction");
+        throw OrthancException("Committing a nonexistent transaction");
       }
       transactionNesting_--;
 
@@ -362,7 +362,7 @@
       if (err != SQLITE_OK)
       {
         delete func;
-        throw PalanthirException("SQLite: Unable to register a function");
+        throw OrthancException("SQLite: Unable to register a function");
       }
 
       return func;
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/Connection.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Connection.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -48,7 +48,7 @@
 
 #define SQLITE_FROM_HERE SQLite::StatementId(__FILE__, __LINE__)
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/FunctionContext.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/FunctionContext.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -35,7 +35,7 @@
 
 #include <sqlite3.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -56,7 +56,7 @@
     {
       if (index >= argc_)
       {
-        throw PalanthirException(ErrorCode_ParameterOutOfRange);
+        throw OrthancException(ErrorCode_ParameterOutOfRange);
       }
     }
 
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/FunctionContext.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/FunctionContext.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -40,7 +40,7 @@
 struct sqlite3_context;
 struct Mem;  // This corresponds to the opaque type "sqlite3_value"
  
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/IScalarFunction.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/IScalarFunction.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -35,7 +35,7 @@
 
 #include "FunctionContext.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/Statement.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Statement.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -43,7 +43,7 @@
 #include <sqlite3.h>
 #include <string.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -52,7 +52,7 @@
       bool succeeded = (err == SQLITE_OK || err == SQLITE_ROW || err == SQLITE_DONE);
       if (!succeeded)
       {
-        throw PalanthirException("SQLite error code " + boost::lexical_cast<std::string>(err));
+        throw OrthancException("SQLite error code " + boost::lexical_cast<std::string>(err));
       }
 
       return err;
@@ -63,11 +63,11 @@
       if (err == SQLITE_RANGE)
       {
         // Binding to a non-existent variable is evidence of a serious error.
-        throw PalanthirException("Bind value out of range");
+        throw OrthancException("Bind value out of range");
       }
       else if (err != SQLITE_OK)
       {
-        throw PalanthirException("SQLite error code " + boost::lexical_cast<std::string>(err));
+        throw OrthancException("SQLite error code " + boost::lexical_cast<std::string>(err));
       }
     }
 
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/Statement.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Statement.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,7 +36,7 @@
 
 #pragma once
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 #include "StatementId.h"
 #include "StatementReference.h"
 
@@ -47,7 +47,7 @@
 struct sqlite3_stmt;
 
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/StatementId.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/StatementId.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -38,7 +38,7 @@
 
 #include <string.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/StatementId.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/StatementId.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,7 +36,7 @@
 
 #pragma once
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/StatementReference.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/StatementReference.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,12 +36,12 @@
 
 #include "StatementReference.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <cassert>
 #include "sqlite3.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -63,7 +63,7 @@
     {
       if (database == NULL || sql == NULL)
       {
-        throw PalanthirException(ErrorCode_ParameterOutOfRange);
+        throw OrthancException(ErrorCode_ParameterOutOfRange);
       }
 
       root_ = NULL;
@@ -72,7 +72,7 @@
       int error = sqlite3_prepare_v2(database, sql, -1, &statement_, NULL);
       if (error != SQLITE_OK)
       {
-        throw PalanthirException("SQLite: " + std::string(sqlite3_errmsg(database)));
+        throw OrthancException("SQLite: " + std::string(sqlite3_errmsg(database)));
       }
 
       assert(IsRoot());
@@ -104,7 +104,7 @@
         if (refCount_ != 0)
         {
           // There remain references to this object
-          throw PalanthirException(ErrorCode_InternalError);
+          throw OrthancException(ErrorCode_InternalError);
         }
         else if (statement_ != NULL)
         {
@@ -115,7 +115,7 @@
       {
         if (root_->refCount_ == 0)
         {
-          throw PalanthirException(ErrorCode_InternalError);
+          throw OrthancException(ErrorCode_InternalError);
         }
         else
         {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/StatementReference.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/StatementReference.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -44,7 +44,7 @@
 struct sqlite3;
 struct sqlite3_stmt;
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/Transaction.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Transaction.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,7 +36,7 @@
 
 #include "Transaction.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -58,13 +58,13 @@
     {
       if (isOpen_) 
       {
-        throw PalanthirException("SQLite: Beginning a transaction twice!");
+        throw OrthancException("SQLite: Beginning a transaction twice!");
       }
 
       isOpen_ = connection_.BeginTransaction();
       if (!isOpen_)
       {
-        throw PalanthirException("SQLite: Unable to create a transaction");
+        throw OrthancException("SQLite: Unable to create a transaction");
       }
     }
 
@@ -72,7 +72,7 @@
     {
       if (!isOpen_) 
       {
-        throw PalanthirException("SQLite: Attempting to roll back a nonexistent transaction. "
+        throw OrthancException("SQLite: Attempting to roll back a nonexistent transaction. "
                                 "Did you remember to call Begin()?");
       }
 
@@ -85,7 +85,7 @@
     {
       if (!isOpen_) 
       {
-        throw PalanthirException("SQLite: Attempting to roll back a nonexistent transaction. "
+        throw OrthancException("SQLite: Attempting to roll back a nonexistent transaction. "
                                 "Did you remember to call Begin()?");
       }
 
@@ -93,7 +93,7 @@
 
       if (!connection_.CommitTransaction())
       {
-        throw PalanthirException("SQLite: Failure when committing the transaction");
+        throw OrthancException("SQLite: Failure when committing the transaction");
       }
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/SQLite/Transaction.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/Transaction.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -38,7 +38,7 @@
 
 #include "Connection.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Toolbox.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Toolbox.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "Toolbox.h"
 
-#include "PalanthirException.h"
+#include "OrthancException.h"
 
 #include <string.h>
 #include <boost/filesystem.hpp>
@@ -39,7 +39,7 @@
 #include "../Resources/md5/md5.h"
 #include "../Resources/base64/base64.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   static bool finish;
 
@@ -125,7 +125,7 @@
     f.open(path, std::ifstream::in | std::ios::binary);
     if (!f.good())
     {
-      throw PalanthirException("Unable to open a file");
+      throw OrthancException("Unable to open a file");
     }
 
     // http://www.cplusplus.com/reference/iostream/istream/tellg/
@@ -150,7 +150,7 @@
       if (boost::filesystem::is_regular_file(path))
         boost::filesystem::remove(path);
       else
-        throw PalanthirException("The path is not a regular file: " + path);
+        throw OrthancException("The path is not a regular file: " + path);
     }
   }
 
@@ -166,7 +166,7 @@
     if (uri.size() == 0 ||
         uri[0] != URI_SEPARATOR)
     {
-      throw PalanthirException(ErrorCode_UriSyntax);
+      throw OrthancException(ErrorCode_UriSyntax);
     }
 
     // Count the number of slashes in the URI to make an assumption
@@ -301,7 +301,7 @@
     }
     catch (boost::filesystem::filesystem_error)
     {
-      throw PalanthirException(ErrorCode_InexistentFile);
+      throw OrthancException(ErrorCode_InexistentFile);
     }
   }
 
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Toolbox.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Toolbox.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -24,7 +24,7 @@
 #include <vector>
 #include <string>
 
-namespace Palanthir
+namespace Orthanc
 {
   typedef std::vector<std::string> UriComponents;
 
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Uuid.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Uuid.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -31,7 +31,7 @@
 #endif
 }
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace Toolbox
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
--- a/Core/Uuid.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Uuid.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -31,7 +31,7 @@
  * http://stackoverflow.com/questions/246930/is-there-any-difference-between-a-guid-and-a-uuid
  **/
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace Toolbox
   {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium